#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <QCoreApplication>
#include <QObject>
#include <QDebug>
#include <QMainWindow>
#include <Eigen/Dense>
#include "include/slam_manager.h"

QT_BEGIN_NAMESPACE
namespace Ui { class MainWindow; }
QT_END_NAMESPACE

class MainWindow : public QMainWindow
{
    Q_OBJECT


public:
    EIGEN_MAKE_ALIGNED_OPERATOR_NEW
    MainWindow(QWidget *parent = nullptr);
    ~MainWindow();

signals:


    void send_rm_outputs(slam::slam_road_model in_rmData);
    void send_odo(double x, double y, double heading);
    void send_ref(std::vector<slam::Vector2d> _line);
    void send_ref_c(std::vector<slam::Vector3d> _line);

private slots:
    void on_actionfocus_triggered();

    void on_actionplay_triggered();

    void on_action3DQuat_triggered();

    void plot_rm_outputs(slam::slam_road_model in_rmData);

    void plot_odo(double x, double y, double heading);
    void plot_ref(std::vector<slam::Vector2d> _line);
    void plot_ref_c(std::vector<slam::Vector3d> _line);
    void on_actionplay_toggled(bool arg1);

private:
    Ui::MainWindow *ui;

    void Create3DFrame();
    void SetSignals();

    void PlotNdm();
    void start();

    void ReadInsData(std::string fp_);
    void ReadInsCAN();
    void ReplayTrajectory();
    void parseCSV();


};
#endif // MAINWINDOW_H
